Re: [GIT PULL] I2C: OMAP: misc. cleanup for v3.2

2011-10-09 Thread Ming Lei
On Thu, Oct 6, 2011 at 12:11 AM, Kevin Hilman khil...@ti.com wrote:
 Ben Dooks ben-...@fluff.org writes:

 On Mon, Sep 26, 2011 at 03:30:50PM -0700, Kevin Hilman wrote:
 ping

 On 09/06/2011 03:31 PM, Kevin Hilman wrote:
 Hi Ben,
 
 On 08/23/2011 05:10 PM, Kevin Hilman wrote:
 Ben,
 
 Here's one more I2C cleanup series for v3.2.
 
 It applies on top of my for_3.2/i2c-fixes branch just submitted.
 
 Please pull into your tree for linux-next.
 
 I see you pulled the other two, can you pull this one as well?

 I've tried, but it seems to note that everything is up to date.

 Is this a suitable branch to pull onto latest so I can reset
 my next tree?

 Yes.

 The i2c-cleanup branch[1] is based on top of the previous two (i2c-andy
 and i2c-fixes) so if you reset your next-i2c branch and just pull
 i2c-cleanup, you'll get all three.

BTW:

The patch[1] is a fix patch, which fix the OOPS[2] during system resume, so
should CC -stable tree.

[1], I2C: OMAP: remove dev-idle, use usage counting provided by runtime PM
[2], http://marc.info/?l=linux-omapm=131658936429671w=2

thanks,
-- 
Ming Lei
--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH 1/5] drivercore: add new error value for deferred probe

2011-10-09 Thread Grant Likely
On Fri, Oct 7, 2011 at 6:12 PM, Greg KH g...@kroah.com wrote:
 On Fri, Oct 07, 2011 at 07:28:33PM -0400, valdis.kletni...@vt.edu wrote:
 On Fri, 07 Oct 2011 16:12:45 MDT, Grant Likely said:
  On Fri, Oct 7, 2011 at 12:43 AM, Greg KH g...@kroah.com wrote:
   On Fri, Oct 07, 2011 at 10:33:06AM +0500, G, Manjunath Kondaiah wrote:

   +#define EPROBE_DEFER 517     /* restart probe again after some time */
  
   Can we really do this?

  According to Arnd, yes this is okay.

    Isn't this some user/kernel api here?

   What's wrong with just overloading on top of an existing error code?
   Surely one of the other 516 types could be used here, right?

  overloading makes it really hard to find the users at a later date.

 Would proposing '#define EPROBE_DEFER EAGAIN' be acceptable to everybody? 
 That
 would allow overloading EAGAIN, but still make it easy to tell the usages 
 apart
 if we need to separate them later...

 Yes, please do that, it is what USB does for it's internal error code
 handling.

Really?  When we've only currently used approximately 2^9 of a 2^31
numberspace?  I'm fine with making sure that the number doesn't show
up in the userspace headers, but it makes no sense to overload the
#defines.  Particularly so in this case where it isn't feasible to
audit every driver to figure out what probe might possibly return.  It
is well within the realm of possibility that existing drivers are
already returning -EAGAIN.

Besides; linux/errno.h *already* has linux-internal error codes that
do not get exported out to userspace.  There is an #ifdef __KERNEL__
block around ERESTARTSYS through EIOCBRETRY which is filtered out when
exporting headers.  I can't see any possible reason why we wouldn't
add Linux internal error codes here.

g.



-- 
Grant Likely, B.Sc., P.Eng.
Secret Lab Technologies Ltd.
--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH 1/5] drivercore: add new error value for deferred probe

2011-10-09 Thread Greg KH
On Sun, Oct 09, 2011 at 04:59:31PM -0600, Grant Likely wrote:
 On Fri, Oct 7, 2011 at 6:12 PM, Greg KH g...@kroah.com wrote:
  On Fri, Oct 07, 2011 at 07:28:33PM -0400, valdis.kletni...@vt.edu wrote:
  On Fri, 07 Oct 2011 16:12:45 MDT, Grant Likely said:
   On Fri, Oct 7, 2011 at 12:43 AM, Greg KH g...@kroah.com wrote:
On Fri, Oct 07, 2011 at 10:33:06AM +0500, G, Manjunath Kondaiah wrote:
 
+#define EPROBE_DEFER 517     /* restart probe again after some time 
*/
   
Can we really do this?
 
   According to Arnd, yes this is okay.
 
 Isn't this some user/kernel api here?
 
What's wrong with just overloading on top of an existing error code?
Surely one of the other 516 types could be used here, right?
 
   overloading makes it really hard to find the users at a later date.
 
  Would proposing '#define EPROBE_DEFER EAGAIN' be acceptable to everybody? 
  That
  would allow overloading EAGAIN, but still make it easy to tell the usages 
  apart
  if we need to separate them later...
 
  Yes, please do that, it is what USB does for it's internal error code
  handling.
 
 Really?  When we've only currently used approximately 2^9 of a 2^31
 numberspace?  I'm fine with making sure that the number doesn't show
 up in the userspace headers, but it makes no sense to overload the
 #defines.  Particularly so in this case where it isn't feasible to
 audit every driver to figure out what probe might possibly return.  It
 is well within the realm of possibility that existing drivers are
 already returning -EAGAIN.

I doubt they are, but you are right, it's really hard to tell.

 Besides; linux/errno.h *already* has linux-internal error codes that
 do not get exported out to userspace.  There is an #ifdef __KERNEL__
 block around ERESTARTSYS through EIOCBRETRY which is filtered out when
 exporting headers.  I can't see any possible reason why we wouldn't
 add Linux internal error codes here.

As long as it stays internal, that's fine, I was worried that this would
be exported to userspace.

Alan, still object to this?

greg k-h
--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[PATCH v4 0/3] Add support for TI814X processor series

2011-10-09 Thread Hemant Pedanekar
This patch set adds support for DM814x/AM387x device series having Cortex-A8
MPU.

The technical documents are available from following link:

http://focus.ti.com/docs/prod/folders/print/tms320dm8148.html

This series is referred in code as TI814X.

Since these devices share similar architecture as TI816X devices, existing
TI816X code is updated to accomodate TI814X support. The code shared across
TI816X and TI814X devices is updated with TI81XX/ti81xx prefix as applicable,
while maintaining cpu_is_ti816x() and cpu_is_ti814x() to distinguish specific
execution differences.

Changes since v3:
1) Avoid renaming board-ti8168evm.c, just add TI8148 EVM support in it.
2) Drop changes in clock related data variables from u8 to u16 since the same
   was incorporated as part of AM33xx addition.

Changes since v2:
1) Incorporate Tony's suggestion about moving ti8168_evm_map_io() to
   arch/arm/mach-omap2/common.c to keep common across TI81XX.
2) Keeping single board file (board-ti81xxevm.c) for TI816X and TI814X EVMs

Changes since v1:
1) Rebased and updated after Paul's CHIP_IS removal changes
2) Removed call to omap2_init_common_devices() as per Kevin's comment

Hemant Pedanekar (3):
  ARM: OMAP: TI81XX: Prepare for addition of TI814X support
  ARM: OMAP: TI814X: Add cpu type macros and detection support
  ARM: OMAP: TI814X: Create board support and enable build for TI8148
EVM

 arch/arm/mach-omap2/Kconfig|   11 +--
 arch/arm/mach-omap2/Makefile   |1 +
 arch/arm/mach-omap2/board-ti8168evm.c  |   33 +++
 arch/arm/mach-omap2/clock3xxx_data.c   |5 ++-
 arch/arm/mach-omap2/common.c   |   27 +--
 arch/arm/mach-omap2/control.h  |8 ++--
 arch/arm/mach-omap2/id.c   |   30 +++--
 arch/arm/mach-omap2/include/mach/debug-macro.S |   12 +++---
 arch/arm/mach-omap2/include/mach/entry-macro.S |4 +-
 arch/arm/mach-omap2/io.c   |   14 
 arch/arm/mach-omap2/irq.c  |2 +-
 arch/arm/mach-omap2/serial.c   |6 ++--
 arch/arm/plat-omap/include/plat/clkdev_omap.h  |1 +
 arch/arm/plat-omap/include/plat/clock.h|1 +
 arch/arm/plat-omap/include/plat/common.h   |6 ++--
 arch/arm/plat-omap/include/plat/cpu.h  |   22 +
 arch/arm/plat-omap/include/plat/hardware.h |2 +-
 arch/arm/plat-omap/include/plat/io.h   |6 ++--
 arch/arm/plat-omap/include/plat/irqs.h |2 +-
 arch/arm/plat-omap/include/plat/serial.h   |   14 
 .../plat-omap/include/plat/{ti816x.h = ti81xx.h}  |   18 +-
 arch/arm/plat-omap/include/plat/uncompress.h   |   11 --
 arch/arm/plat-omap/io.c|2 +-
 23 files changed, 153 insertions(+), 85 deletions(-)
 rename arch/arm/plat-omap/include/plat/{ti816x.h = ti81xx.h} (60%)

-- 
1.7.3.5

--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[PATCH v4 1/3] ARM: OMAP: TI81XX: Prepare for addition of TI814X support

2011-10-09 Thread Hemant Pedanekar
This patch updates existing macros, functions used for TI816X, to enable
addition of other SoCs belonging to TI81XX family (e.g., TI814X).

The approach taken is to use TI81XX/ti81xx for code/data going to be common
across all TI81XX devices.

cpu_is_ti81xx() is introduced to handle code common across TI81XX devices.

In addition, ti8168_evm_map_io() is now replaced with ti81xx_map_io() and moved
in mach-omap2/common.c as same will be used for TI814X and is not board
specific.

Signed-off-by: Hemant Pedanekar hema...@ti.com
---
 arch/arm/mach-omap2/Kconfig|6 ++--
 arch/arm/mach-omap2/board-ti8168evm.c  |   11 ++--
 arch/arm/mach-omap2/clock3xxx_data.c   |2 +-
 arch/arm/mach-omap2/common.c   |   27 +++
 arch/arm/mach-omap2/control.h  |8 +++---
 arch/arm/mach-omap2/id.c   |8 +++---
 arch/arm/mach-omap2/include/mach/debug-macro.S |   12 
 arch/arm/mach-omap2/include/mach/entry-macro.S |4 +-
 arch/arm/mach-omap2/io.c   |   14 +-
 arch/arm/mach-omap2/irq.c  |2 +-
 arch/arm/mach-omap2/serial.c   |6 ++--
 arch/arm/plat-omap/include/plat/common.h   |6 ++--
 arch/arm/plat-omap/include/plat/cpu.h  |   13 +
 arch/arm/plat-omap/include/plat/hardware.h |2 +-
 arch/arm/plat-omap/include/plat/io.h   |6 ++--
 arch/arm/plat-omap/include/plat/irqs.h |2 +-
 arch/arm/plat-omap/include/plat/serial.h   |   14 +-
 .../plat-omap/include/plat/{ti816x.h = ti81xx.h}  |   18 ++--
 arch/arm/plat-omap/include/plat/uncompress.h   |8 +++---
 arch/arm/plat-omap/io.c|2 +-
 20 files changed, 92 insertions(+), 79 deletions(-)
 rename arch/arm/plat-omap/include/plat/{ti816x.h = ti81xx.h} (60%)

diff --git a/arch/arm/mach-omap2/Kconfig b/arch/arm/mach-omap2/Kconfig
index 45498c2..caebeb7 100644
--- a/arch/arm/mach-omap2/Kconfig
+++ b/arch/arm/mach-omap2/Kconfig
@@ -73,8 +73,8 @@ config SOC_OMAP3430
default y
select ARCH_OMAP_OTG
 
-config SOC_OMAPTI816X
-   bool TI816X support
+config SOC_OMAPTI81XX
+   bool TI81XX support
depends on ARCH_OMAP3
default y
 
@@ -322,7 +322,7 @@ config MACH_OMAP_3630SDP
 
 config MACH_TI8168EVM
bool TI8168 Evaluation Module
-   depends on SOC_OMAPTI816X
+   depends on SOC_OMAPTI81XX
default y
 
 config MACH_OMAP_4430SDP
diff --git a/arch/arm/mach-omap2/board-ti8168evm.c 
b/arch/arm/mach-omap2/board-ti8168evm.c
index e6ee884..7935fc9 100644
--- a/arch/arm/mach-omap2/board-ti8168evm.c
+++ b/arch/arm/mach-omap2/board-ti8168evm.c
@@ -35,17 +35,12 @@ static void __init ti8168_evm_init(void)
omap_board_config_size = ARRAY_SIZE(ti8168_evm_config);
 }
 
-static void __init ti8168_evm_map_io(void)
-{
-   omapti816x_map_common_io();
-}
-
 MACHINE_START(TI8168EVM, ti8168evm)
/* Maintainer: Texas Instruments */
.atag_offset= 0x100,
-   .map_io = ti8168_evm_map_io,
-   .init_early = ti816x_init_early,
-   .init_irq   = ti816x_init_irq,
+   .map_io = ti81xx_map_io,
+   .init_early = ti81xx_init_early,
+   .init_irq   = ti81xx_init_irq,
.timer  = omap3_timer,
.init_machine   = ti8168_evm_init,
 MACHINE_END
diff --git a/arch/arm/mach-omap2/clock3xxx_data.c 
b/arch/arm/mach-omap2/clock3xxx_data.c
index 5d0064a..96622b6 100644
--- a/arch/arm/mach-omap2/clock3xxx_data.c
+++ b/arch/arm/mach-omap2/clock3xxx_data.c
@@ -3600,7 +3600,7 @@ int __init omap3xxx_clk_init(void)
 * Lock DPLL5 -- here only until other device init code can
 * handle this
 */
-   if (!cpu_is_ti816x()  (omap_rev() = OMAP3430_REV_ES2_0))
+   if (!cpu_is_ti81xx()  (omap_rev() = OMAP3430_REV_ES2_0))
omap3_clk_lock_dpll5();
 
/* Avoid sleeping during omap3_core_dpll_m2_set_rate() */
diff --git a/arch/arm/mach-omap2/clock3xxx_data.c 
b/arch/arm/mach-omap2/clock3xxx_data.c
index 96622b6..4d8e908 100644
--- a/arch/arm/mach-omap2/clock3xxx_data.c
+++ b/arch/arm/mach-omap2/clock3xxx_data.c
@@ -3517,6 +3517,9 @@ int __init omap3xxx_clk_init(void)
} else if (cpu_is_ti816x()) {
cpu_mask = RATE_IN_TI816X;
cpu_clkflg = CK_TI816X;
+   } else if (cpu_is_ti814x()) {
+   cpu_mask = RATE_IN_TI814X;
+   cpu_clkflg = CK_TI814X;
} else if (cpu_is_omap34xx()) {
if (omap_rev() == OMAP3430_REV_ES1_0) {
cpu_mask = RATE_IN_3430ES1;
diff --git a/arch/arm/mach-omap2/id.c b/arch/arm/mach-omap2/id.c
index ab2f417..f07faa9 100644
--- a/arch/arm/mach-omap2/id.c
+++ b/arch/arm/mach-omap2/id.c
@@ -337,6 +337,26 @@ static void __init omap3_check_revision(const char 
**cpu_rev)
break;
}
break;
+   case 0xb8f2:
+   switch (rev) {
+   case 0:
+   /* FALLTHROUGH */
+   case 1:
+   omap_revision = TI8148_REV_ES1_0;
+   *cpu_rev = 1.0;
+   break;
+   case 2:
+   omap_revision = TI8148_REV_ES2_0;
+   *cpu_rev = 2.0;
+   break;
+   case 3:
+   /* FALLTHROUGH */
+   default:
+   omap_revision = TI8148_REV_ES2_1;
+   *cpu_rev = 2.1;
+   break;
+   }
+   break;
default:
/* Unknown default to latest silicon rev as default */
omap_revision = OMAP3630_REV_ES1_2;
@@ -429,6 +449,8 @@ static void __init omap3_cpuinfo(const char *cpu_rev)
cpu_name = (omap3_has_sgx()) ? AM3517 : AM3505;
} else if (cpu_is_ti816x()) {
cpu_name = TI816X;
+   } else if (cpu_is_ti814x()) {
+   cpu_name = TI814X;
} else if (omap3_has_iva()  omap3_has_sgx()) {
/* OMAP3430, OMAP3525, OMAP3515, OMAP3503 devices */
cpu_name = OMAP3430/3530;
diff --git a/arch/arm/plat-omap/include/plat/clkdev_omap.h 
b/arch/arm/plat-omap/include/plat/clkdev_omap.h
index 6d84c0c..ea61ea2 100644
--- a/arch/arm/plat-omap/include/plat/clkdev_omap.h
+++ b/arch/arm/plat-omap/include/plat/clkdev_omap.h
@@ -41,6 +41,7 @@ struct omap_clk {
 #define CK_TI816X  (1  12)
 #define CK_446X(1  13)
 #define CK_AM33XX  (1  14)   /* AM33xx specific clocks */
+#define CK_TI814X  (1  15)
 
 
 #define CK_34XX(CK_3430ES1 | CK_3430ES2PLUS)
diff --git a/arch/arm/plat-omap/include/plat/clock.h 
b/arch/arm/plat-omap/include/plat/clock.h
index 168c54e..739ba23 100644
--- a/arch/arm/plat-omap/include/plat/clock.h
+++ b/arch/arm/plat-omap/include/plat/clock.h
@@ -60,6 +60,7 @@ struct clkops {
 #define RATE_IN_TI816X (1  6)
 #define RATE_IN_4460   (1  7)
 #define RATE_IN_AM33XX (1  8)
+#define RATE_IN_TI814X (1  9)
 
 #define RATE_IN_24XX   (RATE_IN_242X | RATE_IN_243X)
 #define RATE_IN_34XX   (RATE_IN_3430ES1 | RATE_IN_3430ES2PLUS)
diff --git a/arch/arm/plat-omap/include/plat/cpu.h 
b/arch/arm/plat-omap/include/plat/cpu.h
index 03ab390..6bc662e 100644
--- a/arch/arm/plat-omap/include/plat/cpu.h
+++ b/arch/arm/plat-omap/include/plat/cpu.h
@@ -132,6 +132,7 @@ IS_OMAP_SUBCLASS(443x, 0x443)
 IS_OMAP_SUBCLASS(446x, 0x446)
 
 IS_TI_SUBCLASS(816x, 0x816)
+IS_TI_SUBCLASS(814x, 0x814)
 IS_AM_SUBCLASS(335x, 0x335)
 
 #define cpu_is_omap7xx()   0
@@ -144,6 +145,7 @@ IS_AM_SUBCLASS(335x, 0x335)
 #define cpu_is_omap343x()  0
 #define cpu_is_ti81xx()0
 #define cpu_is_ti816x()0
+#define cpu_is_ti814x()0
 #define cpu_is_am33xx()0
 #define cpu_is_am335x()0
 #define cpu_is_omap44xx()  0
@@ -353,6 +355,7 @@ IS_OMAP_TYPE(3517, 0x3517)
 # undef cpu_is_omap3517
 # undef cpu_is_ti81xx
 # undef cpu_is_ti816x
+# undef cpu_is_ti814x
 # undef cpu_is_am33xx
 # undef cpu_is_am335x
 # define cpu_is_omap3430() is_omap3430()
@@ -373,6 +376,7 @@ IS_OMAP_TYPE(3517, 0x3517)
 # define cpu_is_omap3630() is_omap363x()
 # define cpu_is_ti81xx()   is_ti81xx()
 # define cpu_is_ti816x() 

[PATCH v4 3/3] ARM: OMAP: TI814X: Create board support and enable build for TI8148 EVM

2011-10-09 Thread Hemant Pedanekar
This patch adds minimal support and build configuration for TI8148 EVM. Also
adds support for low level debugging on UART1 console on the EVM.

Note that existing TI8168 EVM file (board-ti8168evm.c) is updated with machine
info for TI8148 EVM.

Signed-off-by: Hemant Pedanekar hema...@ti.com
---
 arch/arm/mach-omap2/Kconfig  |5 +
 arch/arm/mach-omap2/Makefile |1 +
 arch/arm/mach-omap2/board-ti8168evm.c|   22 --
 arch/arm/plat-omap/include/plat/uncompress.h |3 +++
 4 files changed, 25 insertions(+), 6 deletions(-)

diff --git a/arch/arm/mach-omap2/Kconfig b/arch/arm/mach-omap2/Kconfig
index caebeb7..59942b2 100644
--- a/arch/arm/mach-omap2/Kconfig
+++ b/arch/arm/mach-omap2/Kconfig
@@ -325,6 +325,11 @@ config MACH_TI8168EVM
depends on SOC_OMAPTI81XX
default y
 
+config MACH_TI8148EVM
+   bool TI8148 Evaluation Module
+   depends on SOC_OMAPTI81XX
+   default y
+
 config MACH_OMAP_4430SDP
bool OMAP 4430 SDP board
default y
diff --git a/arch/arm/mach-omap2/Makefile b/arch/arm/mach-omap2/Makefile
index 5ee4cd6..0e27e43 100644
--- a/arch/arm/mach-omap2/Makefile
+++ b/arch/arm/mach-omap2/Makefile
@@ -240,6 +240,7 @@ obj-$(CONFIG_MACH_CRANEBOARD)   += 
board-am3517crane.o
 
 obj-$(CONFIG_MACH_SBC3530) += board-omap3stalker.o
 obj-$(CONFIG_MACH_TI8168EVM)   += board-ti8168evm.o
+obj-$(CONFIG_MACH_TI8148EVM)   += board-ti8168evm.o
 
 # Platform specific device init code
 
diff --git a/arch/arm/plat-omap/include/plat/uncompress.h 
b/arch/arm/plat-omap/include/plat/uncompress.h
index a8e5187..27d9d31 100644
--- a/arch/arm/plat-omap/include/plat/uncompress.h
+++ b/arch/arm/plat-omap/include/plat/uncompress.h
@@ -181,6 +181,9 @@ static inline void __arch_decomp_setup(unsigned long 
arch_id)
/* TI8168 base boards using UART3 */
DEBUG_LL_TI81XX(3, ti8168evm);
 
+   /* TI8148 base boards using UART1 */
+   DEBUG_LL_TI81XX(1, ti8148evm);
+
} while (0);
 }
 
-- 
1.7.3.5

--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


RE: [PATCH 3/3] usb: musb: enable support for am335x

2011-10-09 Thread Gupta, Ajay Kumar
Hi,
 On Mon, Sep 26, 2011 at 02:47:11PM +0400, Sergei Shtylyov wrote:
  Hello.
 
  On 26-09-2011 14:03, Ajay Kumar Gupta wrote:
 
  Enabled the flag so that musb_dsps glue file can be used for am335x
 
  Signed-off-by: Ajay Kumar Guptaajay.gu...@ti.com
  ---
drivers/usb/musb/Kconfig |6 +++---
1 files changed, 3 insertions(+), 3 deletions(-)
 
  diff --git a/drivers/usb/musb/Kconfig b/drivers/usb/musb/Kconfig
  index d6abdec..4e21aee 100644
  --- a/drivers/usb/musb/Kconfig
  +++ b/drivers/usb/musb/Kconfig
  @@ -8,7 +8,7 @@ config USB_MUSB_HDRC
 depends on USB  USB_GADGET
 depends on (ARM || (BF54x  !BF544) || (BF52x  !BF522
 !BF523))
 select NOP_USB_XCEIV if (ARCH_DAVINCI || MACH_OMAP3EVM ||
 BLACKFIN)
  -  select NOP_USB_XCEIV if SOC_OMAPTI81XX
  +  select NOP_USB_XCEIV if (SOC_OMAPTI81XX || SOC_OMAPAM33XX)
 select TWL4030_USB if MACH_OMAP_3430SDP
 select TWL6030_USB if MACH_OMAP_4430SDP || MACH_OMAP4_PANDA
 select USB_OTG_UTILS
  @@ -57,7 +57,7 @@ config USB_MUSB_AM35X
  
config USB_MUSB_DSPS
 tristate TI DSPS platforms
  -  depends on SOC_OMAPTI81XX
  +  depends on (SOC_OMAPTI81XX || SOC_OMAPAM33XX)
 
 Parens not needed here and above.
 
 are we getting a revised version ?

Yes, I will send the revised version with earlier set fixing your
comment.

Thanks,
Ajay
 
 --
 balbi
--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[PATCH 0/2] omap: sound: style and warning fixes

2011-10-09 Thread Michael Opdenacker
These patches apply to Tony Lindgren's linux-omap tree
(they can also be applied to Linus' tree)
They fix a warning at compile time and a coding style error.

--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[PATCH 1/2] omap: sound: fix ambiguous else warning

2011-10-09 Thread Michael Opdenacker
This patch applies against Tony Lindgren's linux-omap tree
It fixes ambiguous else warnings at compile time.

Signed-off-by: Michael Opdenacker michael.opdenac...@linaro.org
---
 sound/soc/omap/omap-mcbsp.c |3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)

diff --git a/sound/soc/omap/omap-mcbsp.c b/sound/soc/omap/omap-mcbsp.c
index 478d607..1391ea0 100644
--- a/sound/soc/omap/omap-mcbsp.c
+++ b/sound/soc/omap/omap-mcbsp.c
@@ -516,11 +516,12 @@ static int omap_mcbsp_dai_set_dai_sysclk(struct 
snd_soc_dai *cpu_dai,
struct omap_mcbsp_reg_cfg *regs = mcbsp_data-regs;
int err = 0;
 
-   if (mcbsp_data-active)
+   if (mcbsp_data-active) {
if (freq == mcbsp_data-in_freq)
return 0;
else
return -EBUSY;
+   }
 
/* The McBSP signal muxing functions are only available on McBSP1 */
if (clk_id == OMAP_MCBSP_CLKR_SRC_CLKR ||
-- 
1.7.4.1

--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[PATCH 2/2] omap: sound: fix checkpatch.pl error

2011-10-09 Thread Michael Opdenacker
Signed-off-by: Michael Opdenacker michael.opdenac...@linaro.org
---
 sound/soc/omap/omap-mcbsp.c |3 +--
 1 files changed, 1 insertions(+), 2 deletions(-)

diff --git a/sound/soc/omap/omap-mcbsp.c b/sound/soc/omap/omap-mcbsp.c
index 1391ea0..30325fb 100644
--- a/sound/soc/omap/omap-mcbsp.c
+++ b/sound/soc/omap/omap-mcbsp.c
@@ -606,8 +606,7 @@ static int mcbsp_dai_probe(struct snd_soc_dai *dai)
return 0;
 }
 
-static struct snd_soc_dai_driver omap_mcbsp_dai =
-{
+static struct snd_soc_dai_driver omap_mcbsp_dai = {
.probe = mcbsp_dai_probe,
.playback = {
.channels_min = 1,
diff --git a/arch/arm/mach-omap2/common.c b/arch/arm/mach-omap2/common.c
index 110e5b9..7754e16 100644
--- a/arch/arm/mach-omap2/common.c
+++ b/arch/arm/mach-omap2/common.c
@@ -110,23 +110,28 @@ void __init omap3_map_io(void)
 
 /*
  * Adjust TAP register base such that omap3_check_revision accesses the correct
  * TI816X register for checking device ID (it adds 0x204 to tap base while
  * TI816X DEVICE ID register is at offset 0x600 from control base).
  */
-#define TI816X_TAP_BASE(TI816X_CTRL_BASE + \
-   TI816X_CONTROL_DEVICE_ID - 0x204)
+#define TI81XX_TAP_BASE(TI81XX_CTRL_BASE + \
+   TI81XX_CONTROL_DEVICE_ID - 0x204)
 
-static struct 

[PATCH v4 2/3] ARM: OMAP: TI814X: Add cpu type macros and detection support

2011-10-09 Thread Hemant Pedanekar
This patch adds cpu type, macros for identification of TI814X device.

Signed-off-by: Hemant Pedanekar hema...@ti.com
---
 arch/arm/mach-omap2/clock3xxx_data.c  |3 +++
 arch/arm/mach-omap2/id.c  |   22 ++
 arch/arm/plat-omap/include/plat/clkdev_omap.h |1 +
@@ -110,23 +110,28 @@ void __init omap3_map_io(void)
 /*
  * Adjust TAP register base such that omap3_check_revision accesses the correct
- * TI816X register for checking device ID (it adds 0x204 to tap base while
- * TI816X DEVICE ID register is at offset 0x600 from control base).
+ * TI81XX register for checking device ID (it adds 0x204 to tap base while
+ * TI81XX DEVICE ID register is at offset 0x600 from control base).
  */
 arch/arm/plat-omap/include/plat/clock.h   |1 +
 arch/arm/plat-omap/include/plat/cpu.h |9 +
 5 files changed, 36 insertions(+), 0 deletions(-)

diff --git a/arch/arm/mach-omap2/board-ti8168evm.c 
b/arch/arm/mach-omap2/board-ti8168evm.c
index 7935fc9..b858921 100644
--- a/arch/arm/mach-omap2/board-ti8168evm.c
+++ b/arch/arm/mach-omap2/board-ti8168evm.c
@@ -1,5 +1,5 @@
 /*
  * Code for TI8168 EVM.
  *
  * Copyright (C) 2010 Texas Instruments, Inc. - http://www.ti.com/
  *
@@ -24,15 +24,15 @@
 #include plat/board.h
 #include plat/common.h
 
-static struct omap_board_config_kernel ti8168_evm_config[] __initdata = {
+static struct omap_board_config_kernel ti81xx_evm_config[] __initdata = {
 };
 
-static void __init ti8168_evm_init(void)
+static void __init ti81xx_evm_init(void)
 {
omap_serial_init();
omap_sdrc_init(NULL, NULL);
-   omap_board_config = ti8168_evm_config;
-   omap_board_config_size = ARRAY_SIZE(ti8168_evm_config);
+   omap_board_config = ti81xx_evm_config;
+   omap_board_config_size = ARRAY_SIZE(ti81xx_evm_config);
 }
 
 MACHINE_START(TI8168EVM, ti8168evm)
@@ -42,5 +42,15 @@ MACHINE_START(TI8168EVM, ti8168evm)
.init_early = ti81xx_init_early,
.init_irq   = ti81xx_init_irq,
.timer  = omap3_timer,
-   .init_machine   = ti8168_evm_init,
+   .init_machine   = ti81xx_evm_init,
+MACHINE_END
+
+MACHINE_START(TI8148EVM, ti8148evm)
+   /* Maintainer: Texas Instruments */
+   .atag_offset= 0x100,
+   .map_io = ti81xx_map_io,
+   .init_early = ti81xx_init_early,
+   .init_irq   = ti81xx_init_irq,
+   .timer  = omap3_timer,
+   .init_machine   = ti81xx_evm_init,
 MACHINE_END
@@ -1,5 +1,5 @@
 /*
- * Code for TI8168 EVM.
+ * Code for TI8168/TI8148 EVM.
  *
  * Copyright (C) 2010 Texas Instruments, Inc. - http://www.ti.com/
-- 
1.7.4.1

--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


RE: [PATCH 1/6 v3] omap: musb: Adding hwmod data for ti81xx

2011-10-09 Thread Gupta, Ajay Kumar
Hi,
 On Mon, Sep 26, 2011 at 03:21:07PM +0530, Gupta, Ajay Kumar wrote:
   To: linux-omap@vger.kernel.org
   Cc: linux-...@vger.kernel.org; Balbi, Felipe; t...@atomide.com; B,
   Ravi; Cousson, Benoit; Gupta, Ajay Kumar
   Subject: [PATCH 1/6 v3] omap: musb: Adding hwmod data for ti81xx
 
  Felipe,
  I am planning to send patch 1/6 along with next revision of ti81xx
  hwmod baseport patch from Hemant so that all hwmod data gets reviewed
  at one place.
 
  So now only rest 5 (2/6 to 6/6) patches needs to be queued for usb.
 
  I hope this will be fine with you. Let me know if you want me to post
  Same 5 patches separately.
 
 I guess it's better to queue them separately. I will only take whatever
 lies in drivers/usb/musb

Ok fine so usb hwmod patch will come from Hemant in his hwmod baseport
Series. I will resubmit the one patch fixing your comment. 

Thanks,
Ajay
 
 --
 balbi
--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH 0/2] ARM: OMAP2+: timer fixes / cleanup

2011-10-09 Thread DebBarma, Tarun Kanti
On Wed, Oct 5, 2011 at 3:06 AM, Cousson, Benoit b-cous...@ti.com wrote:
 Hi Tarun,

 On 10/4/2011 11:20 PM, Cousson, Benoit wrote:

 Hi Tony,

 Here is the series to fix the warning and remove the redundant
 latency structure that be removed since the timer runtime PM
 adaptation was just pulled.

 I was just able to test that on OMAP4.

 It will be nice if you can test that on the other platforms.
 In theory, if they are properly using hwmod that should work fine.
Yes, I will test in other platforms.
--
Tarun

 Thanks,
 Benoit


 Patches are based on Kevin's for_3.2/omap_device-2 branch
 and are available here:
 git://gitorious.org/omap-pm/linux.git for_3.2/timer_fixes

 Regards,
 Benoit


 Benoit Cousson (2):
   ARM: OMAP2+: clock data: Remove redundant timer clkdev
   ARM: OMAP2+: timer: Remove omap_device_pm_latency

  arch/arm/mach-omap2/clock2420_data.c |   12 
  arch/arm/mach-omap2/clock2430_data.c |   12 
  arch/arm/mach-omap2/clock3xxx_data.c |   12 
  arch/arm/mach-omap2/clock44xx_data.c |   11 ---
  arch/arm/mach-omap2/timer.c          |   12 +---
  5 files changed, 1 insertions(+), 58 deletions(-)



--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH 1/6 v3] omap: musb: Adding hwmod data for ti81xx

2011-10-09 Thread Felipe Balbi
Hi,

On Mon, Oct 10, 2011 at 10:40:55AM +0530, Gupta, Ajay Kumar wrote:
 Hi,
  On Mon, Sep 26, 2011 at 03:21:07PM +0530, Gupta, Ajay Kumar wrote:
To: linux-omap@vger.kernel.org
Cc: linux-...@vger.kernel.org; Balbi, Felipe; t...@atomide.com; B,
Ravi; Cousson, Benoit; Gupta, Ajay Kumar
Subject: [PATCH 1/6 v3] omap: musb: Adding hwmod data for ti81xx
  
   Felipe,
   I am planning to send patch 1/6 along with next revision of ti81xx
   hwmod baseport patch from Hemant so that all hwmod data gets reviewed
   at one place.
  
   So now only rest 5 (2/6 to 6/6) patches needs to be queued for usb.
  
   I hope this will be fine with you. Let me know if you want me to post
   Same 5 patches separately.
  
  I guess it's better to queue them separately. I will only take whatever
  lies in drivers/usb/musb
 
 Ok fine so usb hwmod patch will come from Hemant in his hwmod baseport
 Series. I will resubmit the one patch fixing your comment. 

ok cool, tks.

For you platform_data stuff (if you have any), you can add a header to
include/linux/platform_data/musb-dsps.h

Or something similar.

-- 
balbi


signature.asc
Description: Digital signature


Re: [PATCH 3/3] usb: musb: enable support for am335x

2011-10-09 Thread Felipe Balbi
On Mon, Oct 10, 2011 at 10:35:15AM +0530, Gupta, Ajay Kumar wrote:
 Hi,
  On Mon, Sep 26, 2011 at 02:47:11PM +0400, Sergei Shtylyov wrote:
   Hello.
  
   On 26-09-2011 14:03, Ajay Kumar Gupta wrote:
  
   Enabled the flag so that musb_dsps glue file can be used for am335x
  
   Signed-off-by: Ajay Kumar Guptaajay.gu...@ti.com
   ---
 drivers/usb/musb/Kconfig |6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)
  
   diff --git a/drivers/usb/musb/Kconfig b/drivers/usb/musb/Kconfig
   index d6abdec..4e21aee 100644
   --- a/drivers/usb/musb/Kconfig
   +++ b/drivers/usb/musb/Kconfig
   @@ -8,7 +8,7 @@ config USB_MUSB_HDRC
depends on USB  USB_GADGET
depends on (ARM || (BF54x  !BF544) || (BF52x  !BF522
  !BF523))
select NOP_USB_XCEIV if (ARCH_DAVINCI || MACH_OMAP3EVM ||
  BLACKFIN)
   -select NOP_USB_XCEIV if SOC_OMAPTI81XX
   +select NOP_USB_XCEIV if (SOC_OMAPTI81XX || SOC_OMAPAM33XX)
select TWL4030_USB if MACH_OMAP_3430SDP
select TWL6030_USB if MACH_OMAP_4430SDP || MACH_OMAP4_PANDA
select USB_OTG_UTILS
   @@ -57,7 +57,7 @@ config USB_MUSB_AM35X
   
 config USB_MUSB_DSPS
tristate TI DSPS platforms
   -depends on SOC_OMAPTI81XX
   +depends on (SOC_OMAPTI81XX || SOC_OMAPAM33XX)
  
  Parens not needed here and above.
  
  are we getting a revised version ?
 
 Yes, I will send the revised version with earlier set fixing your
 comment.

sounds great, tks

-- 
balbi


signature.asc
Description: Digital signature